"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getBackgroundColorType = getBackgroundColorType;

var _tokens = require("../tokens");

var _constants = require("./constants");

/*
Copyright (c) Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
var LIGHT_COLORS = new Set([_tokens.colors.red50, _tokens.colors.red100, _tokens.colors.red200, _tokens.colors.red300, _tokens.colors.green50, _tokens.colors.green100, _tokens.colors.green200, _tokens.colors.green300, _tokens.colors.teal50, _tokens.colors.teal100, _tokens.colors.teal200, _tokens.colors.teal300, _tokens.colors.blue50, _tokens.colors.blue100, _tokens.colors.blue200, _tokens.colors.blue300, _tokens.colors.cobalt50, _tokens.colors.cobalt100, _tokens.colors.cobalt200, _tokens.colors.purple50, _tokens.colors.purple100, _tokens.colors.purple200, _tokens.colors.purple300, _tokens.colors.magenta50, _tokens.colors.magenta100, _tokens.colors.magenta200, _tokens.colors.magenta300, _tokens.colors.brown50, _tokens.colors.brown100, _tokens.colors.brown200, _tokens.colors.brown300, _tokens.colors.orange50, _tokens.colors.orange100, _tokens.colors.orange200, _tokens.colors.orange300, _tokens.colors.orange400, _tokens.colors.lime50, _tokens.colors.lime100, _tokens.colors.lime200, _tokens.colors.lime300, _tokens.colors.lime400, _tokens.colors.platinum50, _tokens.colors.platinum100, _tokens.colors.platinum200, _tokens.colors.platinum300, _tokens.colors.platinum400, _tokens.colors.yellow50, _tokens.colors.yellow100, _tokens.colors.yellow200, _tokens.colors.yellow300, _tokens.colors.yellow400, _tokens.colors.yellow500, _tokens.colors.white, _tokens.colors.gray50, _tokens.colors.gray100, _tokens.colors.gray200, _tokens.colors.gray300, _tokens.colors.gray400]);
var DARK_COLORS = new Set([_tokens.colors.red400, _tokens.colors.red500, _tokens.colors.red600, _tokens.colors.red700, _tokens.colors.green400, _tokens.colors.green500, _tokens.colors.green600, _tokens.colors.green700, _tokens.colors.teal400, _tokens.colors.teal500, _tokens.colors.teal600, _tokens.colors.teal700, _tokens.colors.blue400, _tokens.colors.blue500, _tokens.colors.blue600, _tokens.colors.blue700, _tokens.colors.cobalt300, _tokens.colors.cobalt400, _tokens.colors.cobalt500, _tokens.colors.cobalt600, _tokens.colors.cobalt700, _tokens.colors.purple400, _tokens.colors.purple500, _tokens.colors.purple600, _tokens.colors.purple700, _tokens.colors.magenta400, _tokens.colors.magenta500, _tokens.colors.magenta600, _tokens.colors.magenta700, _tokens.colors.brown400, _tokens.colors.brown500, _tokens.colors.brown600, _tokens.colors.brown700, _tokens.colors.orange500, _tokens.colors.orange600, _tokens.colors.orange700, _tokens.colors.lime500, _tokens.colors.lime600, _tokens.colors.lime700, _tokens.colors.platinum500, _tokens.colors.platinum600, _tokens.colors.platinum700, _tokens.colors.platinum800, _tokens.colors.yellow600, _tokens.colors.yellow700, _tokens.colors.gray500, _tokens.colors.gray600, _tokens.colors.gray700, _tokens.colors.gray800, _tokens.colors.gray900, _tokens.colors.black]);
var POOR_CONTRAST_COLORS = new Set([_tokens.colors.red300, _tokens.colors.gray500, _tokens.colors.yellow600]);

function getBackgroundColorType(backgroundColor) {
  if (process.env.NODE_ENV !== "production" && POOR_CONTRAST_COLORS.has(backgroundColor)) {
    console.warn("The provided value for backgroundColor, ".concat(backgroundColor, ", is not supported because         it does not pass accessibility contrast tests for either white or black text."));
  }

  if (LIGHT_COLORS.has(backgroundColor)) {
    return _constants.BACKGROUND_COLOR_TYPE.light;
  }

  if (DARK_COLORS.has(backgroundColor)) {
    return _constants.BACKGROUND_COLOR_TYPE.dark;
  }

  return null;
}